@@ -11,6 +11,7 @@ pub use crate::core::bits::{Bit, Bits};
 pub use crate::core::block;
 pub use crate::core::block::Block;
 pub use crate::core::check_connected::check_connected;
+pub use crate::core::check_error::check_all;
 pub use crate::core::clock::freq_hz_to_period_femto;
 pub use crate::core::clock::Clock;
 pub use crate::core::clock::NANOS_PER_FEMTO;
@@ -35,6 +36,7 @@ pub use crate::core::simulate::simulate;
 pub use crate::core::simulate::{Sim, SimError, Simulation};
 pub use crate::core::synth::Synth;
 pub use crate::core::synth::VCDValue;
+pub use crate::core::type_descriptor::{TypeDescriptor, TypeField, TypeKind};
 pub use crate::core::vcd_probe::{write_vcd_change, write_vcd_dump, write_vcd_header};
 pub use crate::core::verilog_gen::filter_blackbox_directives;
 pub use crate::core::verilog_gen::VerilogCodeGenerator;
@@ -50,5 +52,3 @@ pub use crate::wait_clock_cycles;
 pub use crate::wait_clock_false;
 pub use crate::wait_clock_true;
 pub use rust_hdl_macros::{hdl_gen, LogicBlock, LogicInterface, LogicState, LogicStruct};
-pub use crate::core::check_error::check_all;
-pub use crate::core::type_descriptor::{TypeDescriptor, TypeKind, TypeField};
\ No newline at end of file
