@@ -4,24 +4,18 @@ use crate::widgets::prelude::*;
 use crate::widgets::sdram::SDRAMDriver;
 
 #[derive(LogicBlock)]
-pub struct SDRAMFIFO<
-    const R: usize,
-    const C: usize,
-    const P: usize,
-    const D: usize,
-    const A: usize,
-    const AP1: usize,
-> {
+pub struct SDRAMFIFO<const R: usize, const C: usize, const P: usize, const D: usize, const A: usize>
+{
     pub clock: Signal<In, Clock>,
     pub sdram: SDRAMDriver<D>,
     pub ram_clock: Signal<In, Clock>,
     pub bus_write: FIFOWriteResponder<Bits<P>>,
     pub bus_read: FIFOReadResponder<Bits<P>>,
-    controller: SDRAMFIFOController<R, C, P, D, A, AP1>,
+    controller: SDRAMFIFOController<R, C, P, D, A>,
 }
 
-impl<const R: usize, const C: usize, const P: usize, const D: usize, const A: usize, const AP1: usize> Logic
-    for SDRAMFIFO<R, C, P, D, A, AP1>
+impl<const R: usize, const C: usize, const P: usize, const D: usize, const A: usize> Logic
+    for SDRAMFIFO<R, C, P, D, A>
 {
     #[hdl_gen]
     fn update(&mut self) {
@@ -39,8 +33,14 @@ impl<const R: usize, const C: usize, const P: usize, const D: usize, const A: us
     }
 }
 
-impl<const R: usize, const C: usize, const P: usize, const D: usize, const A: usize, const AP1: usize> SDRAMFIFO<R, C, P, D, A, AP1> {
-    pub fn new(cas_delay: u32, timings: MemoryTimings, buffer: OutputBuffer) -> SDRAMFIFO<R, C, P, D, A, AP1> {
+impl<const R: usize, const C: usize, const P: usize, const D: usize, const A: usize>
+    SDRAMFIFO<R, C, P, D, A>
+{
+    pub fn new(
+        cas_delay: u32,
+        timings: MemoryTimings,
+        buffer: OutputBuffer,
+    ) -> SDRAMFIFO<R, C, P, D, A> {
         Self {
             clock: Default::default(),
             sdram: Default::default(),
@@ -54,7 +54,11 @@ impl<const R: usize, const C: usize, const P: usize, const D: usize, const A: us
 
 #[test]
 fn test_sdram_fifo_synthesizes() {
-    let mut uut = SDRAMFIFO::<6, 4, 64, 16, 10, 11>::new(3, MemoryTimings::fast_boot_sim(125e6), OutputBuffer::Wired);
+    let mut uut = SDRAMFIFO::<6, 4, 64, 16, 12>::new(
+        3,
+        MemoryTimings::fast_boot_sim(125e6),
+        OutputBuffer::Wired,
+    );
     uut.clock.connect();
     uut.ram_clock.connect();
     uut.bus_read.link_connect_dest();
