@@ -1,8 +1,6 @@
 use crate::core::prelude::*;
-use crate::sim::sdr_sdram::chip::SDRAMSimulator;
 use crate::widgets::dff::DFF;
 use crate::widgets::prelude::{DelayLine, MemoryTimings};
-use crate::widgets::sdram::buffer::SDRAMOnChipBuffer;
 use crate::widgets::sdram::cmd::{SDRAMCommand, SDRAMCommandEncoder};
 use crate::widgets::sdram::SDRAMDriver;
 
@@ -54,7 +52,7 @@ pub struct SDRAMBaseController<const R: usize, const C: usize, const L: usize, c
     t_refresh_max: Constant<Bits<16>>,
     t_rcd: Constant<Bits<16>>,
     t_wr: Constant<Bits<16>>,
-    max_transfer_size: Constant<Bits<4>>,
+    max_transfer_size: Constant<Bits<5>>,
     mode_register: Constant<Bits<13>>,
     cas_delay: Constant<Bits<3>>,
     state: DFF<State>,
@@ -63,7 +61,7 @@ pub struct SDRAMBaseController<const R: usize, const C: usize, const L: usize, c
     reg_address: DFF<Bits<32>>,
     delay_counter: DFF<Bits<16>>,
     refresh_counter: DFF<Bits<16>>,
-    transfer_counter: DFF<Bits<4>>,
+    transfer_counter: DFF<Bits<5>>,
     read_valid: DelayLine<Bit, 8, 3>,
     addr_bank: Signal<Local, Bits<2>>,
     addr_row: Signal<Local, Bits<13>>,
@@ -76,7 +74,7 @@ pub struct SDRAMBaseController<const R: usize, const C: usize, const L: usize, c
     col_bits: Constant<Bits<32>>,
     data_bits: Constant<Bits<L>>,
     data_shift_in: Constant<Bits<L>>,
-    data_out_counter: DFF<Bits<4>>,
+    data_out_counter: DFF<Bits<5>>,
 }
 
 #[derive(Clone, Copy, Debug, PartialEq)]
@@ -95,8 +93,8 @@ impl<const R: usize, const C: usize, const L: usize, const D: usize>
         buffer: OutputBuffer,
     ) -> SDRAMBaseController<R, C, L, D> {
         assert_eq!(L % D, 0);
-        assert!(L / D <= 8);
-        assert_eq!( (1 << C) % (L / D), 0);
+        assert!(L / D <= 16);
+        assert_eq!((1 << C) % (L / D), 0);
         // mode register definitions
         // A2:A0 are the burst length, this design does not use burst transfers
         // so A2:A0 are 0
@@ -377,154 +375,3 @@ impl<const R: usize, const C: usize, const L: usize, const D: usize> Logic
         self.sdram.clk.next = self.clock.val();
     }
 }
-
-#[derive(LogicBlock)]
-struct TestSDRAMDevice {
-    dram: SDRAMSimulator<5, 5, 10, 16>,
-    buffer: SDRAMOnChipBuffer<16>,
-    cntrl: SDRAMBaseController<5, 5, 64, 16>,
-    clock: Signal<In, Clock>,
-}
-
-impl Logic for TestSDRAMDevice {
-    #[hdl_gen]
-    fn update(&mut self) {
-        SDRAMDriver::<16>::join(&mut self.cntrl.sdram, &mut self.buffer.buf_in);
-        SDRAMDriver::<16>::join(&mut self.buffer.buf_out, &mut self.dram.sdram);
-        self.cntrl.clock.next = self.clock.val();
-    }
-}
-
-#[cfg(test)]
-fn make_test_device() -> TestSDRAMDevice {
-    let timings = MemoryTimings::fast_boot_sim(100e6);
-    // Because the buffer adds 1 cycle of read delay
-    // we need to extend the SDRAM CAS by 1 clock.
-    let mut uut = TestSDRAMDevice {
-        dram: SDRAMSimulator::new(timings),
-        buffer: Default::default(),
-        cntrl: SDRAMBaseController::new(3, timings, OutputBuffer::DelayOne),
-        clock: Default::default(),
-    };
-    uut.clock.connect();
-    uut.cntrl.data_in.connect();
-    uut.cntrl.cmd_strobe.connect();
-    uut.cntrl.cmd_address.connect();
-    uut.cntrl.write_not_read.connect();
-    uut.connect_all();
-    uut
-}
-
-#[cfg(test)]
-fn make_test_controller() -> SDRAMBaseController<5, 8, 64, 16> {
-    let timings = MemoryTimings::fast_boot_sim(100e6);
-    let mut uut = SDRAMBaseController::new(3, timings, OutputBuffer::DelayOne);
-    uut.cmd.connect();
-    uut.cmd_strobe.connect();
-    uut.cmd_address.connect();
-    uut.data_in.connect();
-    uut.clock.connect();
-    uut.sdram.link_connect_dest();
-    uut.write_not_read.connect();
-    uut.connect_all();
-    uut
-}
-
-#[test]
-fn test_sdram_controller_is_synthesizable() {
-    let uut = make_test_controller();
-    let vlog = generate_verilog(&uut);
-    yosys_validate("sdram_base_controller", &vlog).unwrap();
-}
-
-#[test]
-fn test_unit_is_synthesizable() {
-    let uut = make_test_device();
-    let vlog = generate_verilog(&uut);
-    yosys_validate("sdram_test_unit", &vlog).unwrap();
-}
-
-#[test]
-fn test_unit_boots() {
-    let uut = make_test_device();
-    let mut sim = Simulation::new();
-    sim.add_clock(5000, |x: &mut Box<TestSDRAMDevice>| {
-        x.clock.next = !x.clock.val()
-    });
-    sim.add_testbench(move |mut sim: Sim<TestSDRAMDevice>| {
-        let mut x = sim.init()?;
-        x = sim.wait(10_000_000, x)?;
-        sim_assert!(sim, !x.dram.test_error.val(), x);
-        sim.done(x)
-    });
-    sim.run_to_file(Box::new(uut), 12_000_000, "base_sdram_boot.vcd")
-        .unwrap()
-}
-
-#[macro_export]
-macro_rules! sdram_basic_write {
-    ($sim: ident, $uut: ident, $cntrl: ident, $addr: expr, $data: expr) => {
-        $uut = $sim.watch(|x| !x.$cntrl.busy.val(), $uut)?;
-        $uut.$cntrl.cmd_address.next = ($addr).into();
-        $uut.$cntrl.write_not_read.next = true;
-        $uut.$cntrl.data_in.next = ($data).into();
-        $uut.$cntrl.cmd_strobe.next = true;
-        wait_clock_cycle!($sim, clock, $uut);
-        $uut.$cntrl.cmd_strobe.next = false;
-        $uut.$cntrl.cmd_address.next = 0_usize.into();
-        $uut.$cntrl.write_not_read.next = false;
-        $uut.$cntrl.data_in.next = 0_usize.into();
-    };
-}
-
-#[macro_export]
-macro_rules! sdram_basic_read {
-    ($sim: ident, $uut: ident, $cntrl: ident, $addr: expr) => {{
-        $uut = $sim.watch(|x| !x.$cntrl.busy.val(), $uut)?;
-        $uut.$cntrl.cmd_address.next = ($addr).into();
-        $uut.$cntrl.write_not_read.next = false;
-        $uut.$cntrl.cmd_strobe.next = true;
-        wait_clock_cycle!($sim, clock, $uut);
-        $uut.$cntrl.cmd_strobe.next = false;
-        $uut.$cntrl.cmd_address.next = 0_usize.into();
-        $uut = $sim.watch(|x| x.$cntrl.data_valid.val(), $uut)?;
-        $uut.$cntrl.data_out.val()
-    }};
-}
-
-#[test]
-fn test_unit_writes() {
-    use rand::Rng;
-    let uut = make_test_device();
-    let mut sim = Simulation::new();
-    let test_data = (0..256)
-        .map(|_| rand::thread_rng().gen::<u64>())
-        .collect::<Vec<_>>();
-    sim.add_clock(5000, |x: &mut Box<TestSDRAMDevice>| {
-        x.clock.next = !x.clock.val()
-    });
-    let send = test_data.clone();
-    let recv = test_data.clone();
-    sim.add_testbench(move |mut sim: Sim<TestSDRAMDevice>| {
-        let mut x = sim.init()?;
-        wait_clock_true!(sim, clock, x);
-        sdram_basic_write!(sim, x, cntrl, 0_usize, 0xDEAD_BEEF_CAFE_BABE_u64);
-        sdram_basic_write!(sim, x, cntrl, 4_usize, 0x1234_ABCD_5678_EFFE_u64);
-        let read = sdram_basic_read!(sim, x, cntrl, 2_usize);
-        wait_clock_cycles!(sim, clock, x, 10);
-        sim_assert_eq!(sim, read, 0x5678_EFFE_DEAD_BEEF_u64, x);
-        let read = sdram_basic_read!(sim, x, cntrl, 4_usize);
-        sim_assert_eq!(sim, read, 0x1234_ABCD_5678_EFFE_u64, x);
-        for (ndx, val) in send.iter().enumerate() {
-            sdram_basic_write!(sim, x, cntrl, ndx * 4 + 8, *val);
-        }
-        for (ndx, val) in recv.iter().enumerate() {
-            let read = sdram_basic_read!(sim, x, cntrl, ndx * 4 + 8);
-            sim_assert_eq!(sim, read, *val, x);
-        }
-        sim_assert!(sim, !x.dram.test_error.val(), x);
-        sim.done(x)
-    });
-    sim.run_to_file(Box::new(uut), 100_000_000, "base_sdram_writes.vcd")
-        .unwrap()
-}
