@@ -58,7 +58,7 @@ impl FaderWithSyncROM {
             strobe: Strobe::new(clock_frequency, 120.0),
             pwm: PulseWidthModulator::default(),
             rom: SyncROM::new(rom),
-            counter: DFF::new(Bits::<8>::default()),
+            counter: Default::default(),
         }
     }
 }
